@@ -131,8 +131,8 @@ class ApiRequest:
             override_verify = verify
 
         try:
-            resp = getattr(requests, method)(
-                url, headers=self.headers, timeout=self.timeout,
+            resp = requests.request(
+                method, url, headers=self.headers, timeout=self.timeout,
                 params=params, json=data, verify=override_verify
             )
             if not resp.ok:
@@ -415,7 +415,7 @@ class SynapseAdmin(ApiRequest):
         self.user = user
 
     def user_list(self, _from, _limit, _guests, _deactivated,
-                  _name, _user_id):
+                  _name, _user_id, _admin=None):
         """List and search users
 
         Args:
@@ -426,11 +426,13 @@ class SynapseAdmin(ApiRequest):
             _name (string): user name localpart to search for, see Synapse
                 admin API docs for details
             _user_id (string): fully qualified Matrix user ID to search for
+            _admin (bool or None): whether to filter for admins. a None
+                does not filter.
 
         Returns:
             string: JSON string containing the found users
         """
-        return self.query("get", "v2/users", params={
+        params = {
             "from": _from,
             "limit": _limit,
             "guests": (str(_guests).lower() if isinstance(_guests, bool)
@@ -438,10 +440,13 @@ class SynapseAdmin(ApiRequest):
             "deactivated": "true" if _deactivated else None,
             "name": _name,
             "user_id": _user_id
-        })
+        }
+        if _admin is not None:
+            params["admins"] = str(_admin).lower()
+        return self.query("get", "v2/users", params=params)
 
     def user_list_paginate(self, _limit, _guests, _deactivated,
-                           _name, _user_id, _from="0"):
+                           _name, _user_id, _from="0", admin=None):
         # documentation is mostly duplicated from user_list...
         """Yields API responses for all of the pagination.
 
@@ -463,7 +468,7 @@ class SynapseAdmin(ApiRequest):
         """
         while _from is not None:
             response = self.user_list(_from, _limit, _guests, _deactivated,
-                                      _name, _user_id)
+                                      _name, _user_id, admin)
             yield response
             _from = response.get("next_token", None)
 
@@ -595,7 +600,7 @@ class SynapseAdmin(ApiRequest):
                           user_id=user_id)
 
     def user_modify(self, user_id, password, display_name, threepid,
-                    avatar_url, admin, deactivation, user_type):
+                    avatar_url, admin, deactivation, user_type, lock):
         """ Create or update information about a given user
 
         Threepid should be passed as a tuple in a tuple
@@ -613,6 +618,8 @@ class SynapseAdmin(ApiRequest):
             data.update({"avatar_url": avatar_url})
         if admin is not None:
             data.update({"admin": admin})
+        if lock is not None:
+            data.update({"locked": lock})
         if deactivation == "deactivate":
             data.update({"deactivated": True})
         if deactivation == "activate":
@@ -853,6 +860,32 @@ class SynapseAdmin(ApiRequest):
         return self.query("delete", "v1/rooms/{room_id}", data=data,
                           room_id=room_id)
 
+    def room_delete_v2(self, room_id, new_room_user_id, room_name, message,
+                       block, purge):
+        """ Delete a room asynchronously and purge it if requested
+        """
+        data = {
+            "block": block,  # data with proper defaults from cli
+            "purge": purge
+        }
+        # everything else is optional and shouldn't even exist in post body
+        if new_room_user_id:
+            data.update({"new_room_user_id": new_room_user_id})
+        if room_name:
+            data.update({"room_name": room_name})
+        if message:
+            data.update({"message": message})
+        return self.query("delete", "v2/rooms/{room_id}", data=data,
+                          room_id=room_id)
+
+    def room_delete_v2_status_by_room_id(self, room_id):
+        return self.query("get", "v2/rooms/{room_id}/delete_status",
+                          room_id=room_id)
+
+    def room_delete_v2_status_by_delete_id(self, delete_id):
+        return self.query("get", "v2/rooms/delete_status/{delete_id}",
+                          delete_id=delete_id)
+
     def block_room(self, room_id, block):
         """ Block or unblock a room.
 
@@ -1312,7 +1345,7 @@ class SynapseAdmin(ApiRequest):
         # A regular expression was supplied to match receivers.
         if regex:
             outputs = []
-            response = self.user_list(0, paginate, True, False, "", "")
+            response = self.user_list(0, paginate, True, False, "", "", None)
             if "users" not in response:
                 return
             while True:
@@ -1328,7 +1361,7 @@ class SynapseAdmin(ApiRequest):
                 if "next_token" not in response:
                     return outputs
                 response = self.user_list(response["next_token"],
-                                          100, True, False, "", "")
+                                          100, True, False, "", "", None)
         # Only a single user ID was supplied as receiver
         else:
             data["user_id"] = receivers
