@@ -141,11 +141,11 @@ class APIHelper:
             self.log.error("%s while reading configuration file", error)
         for key, value in self.config.items():
 
-            if key == "ssl_verify" and type(value) != bool:
+            if key == "ssl_verify" and not isinstance(value, bool):
                 self.log.error("Config value error: %s, %s must be boolean",
                                key, value)
 
-            if not value and type(value) != bool:
+            if not value and not isinstance(value, bool):
                 self.log.error("Config entry missing: %s, %s", key, value)
                 return False
             else:
@@ -300,6 +300,7 @@ class APIHelper:
 @click.group(
     invoke_without_command=False,
     context_settings=dict(help_option_names=["-h", "--help"]))
+@click.version_option()
 @click.option(
     "--verbose", "-v", count=True, default=False,
     help="Enable INFO (-v) or DEBUG (-vv) logging on console.")
