@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # synadm
-# Copyright (C) 2020-2022 Johannes Tiefenbacher
+# Copyright (C) 2020-2023 Johannes Tiefenbacher
 #
 # synadm is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ from synadm import cli
 
 @cli.root.group()
 def history():
-    """ Purge historic events from Synapse database
+    """ Purge historic events from Synapse database.
     """
 
 
@@ -82,7 +82,7 @@ def history_purge_cmd(helper, room_id, before_event_id, before_days, before,
     poll for updates on the running purge.
     """
     sure = (
-        helper.batch or
+        helper.no_confirm or
         click.prompt("Are you sure you want to purge room history? (y/N)",
                      type=bool, default=False, show_default=False)
     )
@@ -92,7 +92,7 @@ def history_purge_cmd(helper, room_id, before_event_id, before_days, before,
             delete_local
         )
 
-        if helper.batch:
+        if helper.no_confirm:
             helper.output(history_purged)
             if history_purged is None:
                 raise SystemExit(1)
@@ -112,12 +112,13 @@ def history_purge_cmd(helper, room_id, before_event_id, before_days, before,
 @click.argument("purge_id", type=str)
 @click.pass_obj
 def history_purge_status_cmd(helper, purge_id):
-    """ View status of a recent history purge. Provide purge ID as argument.
+    """ View status of a recent history purge..
 
-    The status will be one of active, complete, or failed.
+    Provide purge ID as argument. The status will be one of active, complete,
+    or failed.
     """
     purge_history_status = helper.api.purge_history_status(purge_id)
-    if helper.batch:
+    if helper.no_confirm:
         if purge_history_status is None:
             raise SystemExit(1)
         helper.output(purge_history_status)
