@@ -53,6 +53,10 @@ def user():
 @click.option(
     "--deactivated", "-d", is_flag=True, default=False,
     help="Also show deactivated/erased users", show_default=True)
+@click.option(
+    "--admins/--non-admins", "-a/-A", default=None,
+    help="""Whether to filter for admins, or non-admins. If not specified,
+    no admin filter is applied.""")
 @optgroup.group(
     "Search options",
     cls=MutuallyExclusiveOptionGroup,
@@ -67,12 +71,13 @@ def user():
     help="""Search users by ID - filters to only return users with Matrix IDs
     (@user:server) that contain this value""")
 @click.pass_obj
-def list_user_cmd(helper, from_, limit, guests, deactivated, name, user_id):
+def list_user_cmd(helper, from_, limit, guests, deactivated, name, user_id,
+                  admins):
     """ List users, search for users.
     """
     mxid = helper.generate_mxid(user_id)
     users = helper.api.user_list(from_, limit, guests, deactivated, name,
-                                 mxid)
+                                 mxid, admins)
     if users is None:
         click.echo("Users could not be fetched.")
         raise SystemExit(1)
@@ -423,10 +428,14 @@ class UserModifyOptionGroup(RequiredAnyOptionGroup):
     is omitted when modifying an existing user, the user-type will not be
     manipulated. If the --user-type option is omitted when creating a new user,
     a regular user will be created.""")
+@optgroup.option(
+    "--lock/--unlock", "-l/-L", default=None, show_default=False,
+    help="""Whether to lock or unlock the account, preventing or allowing
+    logins respectively. Feature first present in Synapse 1.91.0.""")
 @click.pass_obj
 @click.pass_context
 def modify(ctx, helper, user_id, password, password_prompt, display_name,
-           threepid, avatar_url, admin, deactivation, user_type):
+           threepid, avatar_url, admin, deactivation, user_type, lock):
     """ Create or modify a local user. Provide matrix user ID (@user:server)
     as argument.
     """
@@ -480,7 +489,7 @@ def modify(ctx, helper, user_id, password, password_prompt, display_name,
         modified = helper.api.user_modify(
             mxid, password, display_name, threepid,
             avatar_url, admin, deactivation,
-            'null' if user_type == 'regular' else user_type)
+            'null' if user_type == 'regular' else user_type, lock)
         if modified is None:
             click.echo("User could not be modified.")
             raise SystemExit(1)
